==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/mixer/v1/CheckRequestFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Boolean;
import java.util.Map;

public interface CheckRequestFluent<A extends CheckRequestFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAttributes instead.
 * @return The buildable object.
 */
@Deprecated public CompressedAttributes getAttributes();
    public CompressedAttributes buildAttributes();
    public A withAttributes(CompressedAttributes attributes);
    public Boolean hasAttributes();
    public CheckRequestFluent.AttributesNested<A> withNewAttributes();
    public CheckRequestFluent.AttributesNested<A> withNewAttributesLike(CompressedAttributes item);
    public CheckRequestFluent.AttributesNested<A> editAttributes();
    public CheckRequestFluent.AttributesNested<A> editOrNewAttributes();
    public CheckRequestFluent.AttributesNested<A> editOrNewAttributesLike(CompressedAttributes item);
    public String getDeduplicationId();
    public A withDeduplicationId(String deduplicationId);
    public Boolean hasDeduplicationId();
    public Integer getGlobalWordCount();
    public A withGlobalWordCount(Integer globalWordCount);
    public Boolean hasGlobalWordCount();
    public A withNewGlobalWordCount(String arg1);
    public A withNewGlobalWordCount(int arg1);
    public A addToQuotas(String key,QuotaParams value);
    public A addToQuotas(Map<String,QuotaParams> map);
    public A removeFromQuotas(String key);
    public A removeFromQuotas(Map<String,QuotaParams> map);
    public Map<String,QuotaParams> getQuotas();
    public A withQuotas(Map<String,QuotaParams> quotas);
    public Boolean hasQuotas();

    public interface AttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CompressedAttributesFluent<CheckRequestFluent.AttributesNested<N>>{

        
    public N and();    public N endAttributes();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/mixer/v1/CheckRequestFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface CheckRequestFluent<A extends CheckRequestFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAttributes instead.
 * @return The buildable object.
 */
@Deprecated public CompressedAttributes getAttributes();
    public CompressedAttributes buildAttributes();
    public A withAttributes(CompressedAttributes attributes);
    public Boolean hasAttributes();
    public CheckRequestFluent.AttributesNested<A> withNewAttributes();
    public CheckRequestFluent.AttributesNested<A> withNewAttributesLike(CompressedAttributes item);
    public CheckRequestFluent.AttributesNested<A> editAttributes();
    public CheckRequestFluent.AttributesNested<A> editOrNewAttributes();
    public CheckRequestFluent.AttributesNested<A> editOrNewAttributesLike(CompressedAttributes item);
    public String getDeduplicationId();
    public A withDeduplicationId(String deduplicationId);
    public Boolean hasDeduplicationId();
    public A withNewDeduplicationId(String arg1);
    public A withNewDeduplicationId(StringBuilder arg1);
    public A withNewDeduplicationId(StringBuffer arg1);
    public Integer getGlobalWordCount();
    public A withGlobalWordCount(Integer globalWordCount);
    public Boolean hasGlobalWordCount();
    public A addToQuotas(String key,QuotaParams value);
    public A addToQuotas(Map<String,QuotaParams> map);
    public A removeFromQuotas(String key);
    public A removeFromQuotas(Map<String,QuotaParams> map);
    public Map<String,QuotaParams> getQuotas();
    public A withQuotas(Map<String,QuotaParams> quotas);
    public Boolean hasQuotas();

    public interface AttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CompressedAttributesFluent<CheckRequestFluent.AttributesNested<N>>{

        
    public N and();    public N endAttributes();
}


}
